@@ -27,13 +27,14 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <libgnomevfs/gnome-vfs-i18n.h>
 #include <libgnomevfs/gnome-vfs-module-shared.h>
 #include <libgnomevfs/gnome-vfs-module.h>
 #include <libgnomevfs/gnome-vfs-volume-monitor.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-monitor-private.h>
 
+#include <glib/gi18n-lib.h>
+
 typedef enum {
 	COMPUTER_HOME_LINK,
 	COMPUTER_ROOT_LINK,
@@ -308,10 +309,16 @@ drive_connected (GnomeVFSVolumeMonitor *volume_monitor,
 		 ComputerDir           *dir)
 {
 	ComputerFile *file;
+	GnomeVFSVolume *volume;
 	char *name;
 	
 	G_LOCK (root_dir);
-	if (gnome_vfs_drive_is_user_visible (drive)) {
+	/* This is a hacky workaround for the fact that the
+	 * hal backend creates drive objects for "normal" mountpoints.
+	 * See #341446 for details.
+	 */
+	volume = gnome_vfs_drive_get_mounted_volume (drive);
+	if (volume == NULL || gnome_vfs_volume_is_user_visible (volume)) {
 		file = computer_file_new (COMPUTER_DRIVE);
 		name = gnome_vfs_drive_get_display_name (drive);
 		file->file_name = build_file_name (name, ".drive");
@@ -319,6 +326,9 @@ drive_connected (GnomeVFSVolumeMonitor *volume_monitor,
 		file->drive = gnome_vfs_drive_ref (drive);
 		computer_file_add (dir, file);
 	}
+	if (volume != NULL) {
+		gnome_vfs_volume_unref (volume);
+	}
 	G_UNLOCK (root_dir);
 }
 
@@ -368,8 +378,14 @@ fill_root (ComputerDir *dir)
 	drives = gnome_vfs_volume_monitor_get_connected_drives (monitor);
 	
 	for (l = drives; l != NULL; l = l->next) {
+		GnomeVFSVolume *volume;
 		drive = l->data;
-		if (gnome_vfs_drive_is_user_visible (drive)) {
+		/* This is a hacky workaround for the fact that the
+		 * hal backend creates drive objects for "normal" mountpoints.
+		 * See #341446 for details.
+		 */
+		volume = gnome_vfs_drive_get_mounted_volume (drive);
+		if (volume == NULL || gnome_vfs_volume_is_user_visible (volume)) {
 			file = computer_file_new (COMPUTER_DRIVE);
 			name = gnome_vfs_drive_get_display_name (drive);
 			file->file_name = build_file_name (name, ".drive");
@@ -377,6 +393,9 @@ fill_root (ComputerDir *dir)
 			file->drive = gnome_vfs_drive_ref (drive);
 			computer_file_add (dir, file);
 		}
+		if (volume != NULL) {
+			gnome_vfs_volume_unref (volume);
+		}
 	}
 	
 	for (l = volumes; l != NULL; l = l->next) {
@@ -755,7 +774,7 @@ do_seek (GnomeVFSMethod *method,
 static GnomeVFSResult
 do_tell (GnomeVFSMethod *method,
 	 GnomeVFSMethodHandle *method_handle,
-	 GnomeVFSFileOffset *offset_return)
+	 GnomeVFSFileSize *offset_return)
 {
 	FileHandle *file_handle;
 
